Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MaxRequestBodySize ¶
MaxRequestBodySize limits request bodies to maxBytes.
func Recovery ¶
Recovery returns a middleware that recovers from panics, logs the error and stack trace, and returns a 500 response.
func RequestLogger ¶
RequestLogger returns a middleware that logs each HTTP request using slog.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.