Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewRouter ¶
func NewRouter(cfg RouterConfig) http.Handler
NewRouter builds and returns the application HTTP handler.
Types ¶
type RouterConfig ¶
type RouterConfig struct {
Auth config.Secret
Logger *slog.Logger
StartTime time.Time
DB *sql.DB
DBType string
DBPath string
ConfigFile string
TMDBKeyConfigured bool
TMDBKeyIsDefault bool
LogSystem *beaconlog.System
DockerLogs *beaconlog.DockerLogsReader
Queries db.Querier
ShowService *show.Service
QualityService *quality.Service
LibraryService *library.Service
IndexerService *indexer.Service
DownloaderService *downloader.Service
NotificationService *notification.Service
MediaServerService *mediaserver.Service
BlocklistService *blocklist.Service
MediaManagementService *mediamanagement.Service
QualityDefService *quality.DefinitionService
QueueService *queue.Service
ImporterService *importer.Service
ActivityService *activity.Service
StatsService *stats.Service
ImportListService *importlist.Service
SonarrImportService *sonarrimport.Service
ProviderResolver *provider.Resolver
WSHub *ws.Hub
Scheduler *scheduler.Scheduler
PulseSyncHandler http.HandlerFunc
}
RouterConfig holds everything the router needs to function.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package ws implements a WebSocket hub that bridges the internal event bus to connected browser clients.
|
Package ws implements a WebSocket hub that bridges the internal event bus to connected browser clients. |
Click to show internal directories.
Click to hide internal directories.